package net.knarcraft.bookswithoutborders.command;

import net.knarcraft.bookswithoutborders.BooksWithoutBorders;
import net.knarcraft.bookswithoutborders.config.BooksWithoutBordersConfig;
import net.knarcraft.bookswithoutborders.utility.EconomyHelper;
import net.knarcraft.bookswithoutborders.utility.InputCleaningHelper;
import net.knarcraft.bookswithoutborders.utility.InventoryHelper;
import net.knarcraft.bookswithoutborders.utility.TabCompletionHelper;
import org.bukkit.command.Command;
import org.bukkit.command.CommandSender;
import org.bukkit.command.TabExecutor;
import org.bukkit.entity.Player;
import org.bukkit.inventory.ItemStack;
import org.bukkit.inventory.meta.BookMeta;
import org.jetbrains.annotations.NotNull;

import java.util.ArrayList;
import java.util.List;
import java.util.Objects;

/**
 * Command executor for the copy command
 */
public class CommandCopy implements TabExecutor {

    @Override
    public boolean onCommand(@NotNull CommandSender sender, @NotNull Command command, @NotNull String label, @NotNull String[] args) {
        if (!(sender instanceof Player player)) {
            BooksWithoutBorders.sendErrorMessage(sender, "This command can only be used by a player!");
            return false;
        }

        if (InventoryHelper.notHoldingOneWrittenBookCheck(player, "You must be holding a written book to copy it!",
                "You cannot copy two books at once!")) {
            return false;
        }

        if (args.length < 1) {
            BooksWithoutBorders.sendErrorMessage(player, "You must specify the number of copies to be made!");
            return false;
        }

        ItemStack heldBook = InventoryHelper.getHeldBook(player, true);

        try {
            int copies = Integer.parseInt(args[0]);
            if (copies > 0) {
                if (BooksWithoutBordersConfig.getAuthorOnlyCopy() && !player.hasPermission("bookswithoutborders.bypassAuthorOnlyCopy")) {
                    if (!isAuthor(player, (BookMeta) Objects.requireNonNull(heldBook.getItemMeta()))) {
                        return false;
                    }
                }

                if (BooksWithoutBordersConfig.booksHavePrice() &&
                        !player.hasPermission("bookswithoutborders.bypassBookPrice") &&
                        EconomyHelper.cannotPayForBookPrinting(player, copies)) {
                    return false;
                }

                heldBook.setAmount(heldBook.getAmount() + copies);
                BooksWithoutBorders.sendSuccessMessage(player, "Book copied!");
                return true;
            }
        } catch (NumberFormatException ignored) {
        }
        BooksWithoutBorders.sendErrorMessage(player, "Book not copied!");
        BooksWithoutBorders.sendErrorMessage(player, "Number specified was invalid!");
        return false;
    }

    /**
     * Checks whether the given player is the author of a given book
     *
     * @param player <p>The player to check</p>
     * @param book   <p>The book to check</p>
     * @return <p>True if the player is the book's author</p>
     */
    private boolean isAuthor(Player player, BookMeta book) {
        String author = book.getAuthor();
        String playerName = InputCleaningHelper.cleanString(player.getName());
        if (author != null && playerName.equalsIgnoreCase(InputCleaningHelper.cleanString(author))) {
            return true;
        }

        BooksWithoutBorders.sendErrorMessage(player, "You must be the author of this book to use this command!");
        return false;
    }

    @Override
    public List<String> onTabComplete(@NotNull CommandSender sender, @NotNull Command command, @NotNull String alias, @NotNull String[] args) {
        int argumentCount = args.length;
        if (argumentCount == 1) {
            return TabCompletionHelper.getNumbers(1, 20);
        }
        return new ArrayList<>();
    }

}
