package net.knarcraft.bookswithoutborders.command;

import net.knarcraft.bookswithoutborders.BooksWithoutBorders;
import net.knarcraft.bookswithoutborders.config.BooksWithoutBordersConfig;
import net.knarcraft.bookswithoutborders.utility.EncryptionHelper;
import net.knarcraft.bookswithoutborders.utility.InventoryHelper;
import org.bukkit.command.Command;
import org.bukkit.command.CommandSender;
import org.bukkit.command.TabExecutor;
import org.bukkit.entity.Player;
import org.bukkit.inventory.ItemStack;
import org.bukkit.inventory.meta.BookMeta;
import org.jetbrains.annotations.NotNull;

import java.io.File;
import java.util.ArrayList;
import java.util.List;

import static net.knarcraft.bookswithoutborders.config.BooksWithoutBordersConfig.getBookFolder;
import static net.knarcraft.bookswithoutborders.config.BooksWithoutBordersConfig.getSlash;

/**
 * Command executor for the decrypt command
 */
public class CommandDecrypt implements TabExecutor {

    @Override
    public boolean onCommand(@NotNull CommandSender sender, @NotNull Command command, @NotNull String label, @NotNull String[] args) {
        if (!(sender instanceof Player player)) {
            BooksWithoutBorders.sendErrorMessage(sender, "This command can only be used by a player!");
            return false;
        }

        if (InventoryHelper.notHoldingOneWrittenBookCheck(player,
                "You must be holding a written book to decrypt it!",
                "You cannot decrypt two books at once!")) {
            return false;
        }

        ItemStack heldItem = InventoryHelper.getHeldBook(player, true);
        BookMeta bookMetadata = (BookMeta) heldItem.getItemMeta();
        if (bookMetadata == null) {
            BooksWithoutBorders.sendErrorMessage(player, "Your book seems to be corrupt!");
            return false;
        }

        //Warning: admin decrypt only allows decrypting files created by the same player. Not sure if intended
        if (args.length == 0 && BooksWithoutBordersConfig.getAdminDecrypt() && player.hasPermission("bookswithoutborders.admin")) {
            String path = getBookFolder() + "Encrypted" + getSlash();
            String fileName;
            if (bookMetadata.hasTitle()) {
                fileName = bookMetadata.getTitle() + BooksWithoutBordersConfig.getTitleAuthorSeparator() + bookMetadata.getAuthor();
            } else {
                fileName = "Untitled," + player.getName();
            }

            File encryptedDirectory = new File(path);
            String[] encryptedFiles = encryptedDirectory.list();
            if (encryptedFiles == null) {
                BooksWithoutBorders.sendErrorMessage(player, "Could not find any encrypted files!");
                return false;
            }

            //Get the "encryption key" from the filename
            String key = "";
            for (String encryptedFile : encryptedFiles) {
                if (encryptedFile.contains(fileName)) {
                    key = encryptedFile.substring(encryptedFile.indexOf("[") + 1, encryptedFile.indexOf("]"));
                    break;
                }
            }

            if (!key.equalsIgnoreCase("")) {
                //Decrypt the book
                ItemStack book = EncryptionHelper.loadEncryptedBook(player, key, false);
                if (book != null) {
                    InventoryHelper.setHeldWrittenBook(player, book);
                    BooksWithoutBorders.sendSuccessMessage(player, "Book auto-decrypted!");
                    return true;
                } else {
                    return false;
                }
            } else {
                BooksWithoutBorders.sendErrorMessage(player, "No matching encrypted book found!");
                return false;
            }
        } else if (args.length == 0) {
            BooksWithoutBorders.sendErrorMessage(player, "No decryption password given!");
            return false;
        }

        String key = EncryptionHelper.getNumberKeyFromStringKey(args[0]);

        //Decrypt the book
        ItemStack book = EncryptionHelper.loadEncryptedBook(player, key, true);
        if (book != null) {
            InventoryHelper.setHeldWrittenBook(player, book);
            BooksWithoutBorders.sendSuccessMessage(player, "Book decrypted!");
            return true;
        } else {
            BooksWithoutBorders.sendErrorMessage(player, "Failed to decrypt book!");
            return false;
        }
    }

    @Override
    public List<String> onTabComplete(@NotNull CommandSender sender, @NotNull Command command, @NotNull String alias, @NotNull String[] args) {
        int argumentCount = args.length;
        if (argumentCount == 1) {
            List<String> info = new ArrayList<>();
            info.add("<password>");
            return info;
        }
        return new ArrayList<>();
    }

}
