package net.knarcraft.bookswithoutborders.command;

import net.knarcraft.bookswithoutborders.BooksWithoutBorders;
import net.knarcraft.bookswithoutborders.state.ItemSlot;
import net.knarcraft.bookswithoutborders.utility.InventoryHelper;
import org.bukkit.command.Command;
import org.bukkit.command.CommandSender;
import org.bukkit.command.TabExecutor;
import org.bukkit.entity.Player;
import org.bukkit.inventory.ItemStack;
import org.bukkit.inventory.meta.BookMeta;
import org.jetbrains.annotations.NotNull;

import java.util.ArrayList;
import java.util.List;

/**
 * Command executor for the set author command
 */
public class CommandSetAuthor implements TabExecutor {

    @Override
    public boolean onCommand(@NotNull CommandSender sender, @NotNull Command command, @NotNull String label, @NotNull String[] args) {
        if (!(sender instanceof Player player)) {
            BooksWithoutBorders.sendErrorMessage(sender, "This command can only be used by a player!");
            return false;
        }

        if (args.length < 1) {
            BooksWithoutBorders.sendErrorMessage(player, "Too few command arguments!");
            return false;
        }

        if (InventoryHelper.notHoldingOneWrittenBookCheck(player,
                "You must be holding a written book to set author!", "You cannot set the " +
                        "author of two books at once!")) {
            return false;
        }

        ItemSlot heldBookSlot = InventoryHelper.getHeldSlotBook(player, false, false, true, true);
        boolean mainHand = heldBookSlot == ItemSlot.MAIN_HAND;
        ItemStack heldBook = InventoryHelper.getHeldItem(player, mainHand);
        BookMeta bookMetaData = InventoryHelper.getHeldBookMetadata(player, mainHand);

        String author = String.join(" ", args);
        bookMetaData.setAuthor(author);
        heldBook.setItemMeta(bookMetaData);
        BooksWithoutBorders.sendSuccessMessage(player, "Book author set to " + author + "!");
        return true;
    }

    @Override
    public List<String> onTabComplete(@NotNull CommandSender sender, @NotNull Command command, @NotNull String alias, String[] args) {
        if (args.length == 1) {
            return null;
        } else {
            return new ArrayList<>();
        }
    }

}
