package net.knarcraft.bookswithoutborders.command;

import net.knarcraft.bookswithoutborders.BooksWithoutBorders;
import net.knarcraft.bookswithoutborders.config.BooksWithoutBordersConfig;
import net.knarcraft.bookswithoutborders.utility.InventoryHelper;
import org.bukkit.ChatColor;
import org.bukkit.Material;
import org.bukkit.command.Command;
import org.bukkit.command.CommandSender;
import org.bukkit.command.TabExecutor;
import org.bukkit.entity.Player;
import org.bukkit.inventory.ItemStack;
import org.bukkit.inventory.meta.ItemMeta;
import org.jetbrains.annotations.NotNull;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

/**
 * Command executor for the set lore command
 */
public class CommandSetLore implements TabExecutor {

    @Override
    public boolean onCommand(@NotNull CommandSender sender, @NotNull Command command, @NotNull String label, @NotNull String[] args) {
        if (!(sender instanceof Player player)) {
            BooksWithoutBorders.sendErrorMessage(sender, "This command can only be used by a player!");
            return false;
        }

        if (args.length < 1) {
            BooksWithoutBorders.sendErrorMessage(player, "Missing a command argument!");
            return false;
        }

        ItemStack heldItem = InventoryHelper.getHeldItem(player, true);
        if (heldItem.getType() == Material.AIR) {
            BooksWithoutBorders.sendErrorMessage(player, "Must be holding an item to set lore!");
            return false;
        }

        //Treat all arguments as lore input
        String rawLore = String.join(" ", args);

        //Format lore
        rawLore = ChatColor.translateAlternateColorCodes('&', rawLore);
        String[] loreParts = rawLore.split(BooksWithoutBordersConfig.getLoreSeparator());
        List<String> newLore = new ArrayList<>(Arrays.asList(loreParts));

        //Update lore
        ItemMeta meta = heldItem.getItemMeta();
        if (meta == null) {
            BooksWithoutBorders.sendErrorMessage(player, "Could not get metadata from the held item!");
            return false;
        }
        meta.setLore(newLore);
        heldItem.setItemMeta(meta);
        BooksWithoutBorders.sendSuccessMessage(player, "Added lore to item!");
        return true;
    }

    @Override
    public List<String> onTabComplete(@NotNull CommandSender sender, @NotNull Command command, @NotNull String alias, String[] args) {
        //TODO: Figure out if there is a better way to display that an argument is required
        List<String> options = new ArrayList<>();
        options.add("<new lore>");
        return options;
    }

}
