package net.knarcraft.bookswithoutborders.command;

import net.knarcraft.bookswithoutborders.BooksWithoutBorders;
import net.knarcraft.bookswithoutborders.utility.InventoryHelper;
import org.bukkit.ChatColor;
import org.bukkit.Material;
import org.bukkit.command.Command;
import org.bukkit.command.CommandSender;
import org.bukkit.command.TabExecutor;
import org.bukkit.entity.Player;
import org.bukkit.inventory.ItemStack;
import org.bukkit.inventory.meta.BookMeta;
import org.bukkit.inventory.meta.ItemMeta;
import org.jetbrains.annotations.NotNull;

import java.util.ArrayList;
import java.util.List;

/**
 * Command executor for the set title command
 */
public class CommandSetTitle implements TabExecutor {

    @Override
    public boolean onCommand(@NotNull CommandSender sender, @NotNull Command command, @NotNull String label, @NotNull String[] args) {
        if (!(sender instanceof Player player)) {
            BooksWithoutBorders.sendErrorMessage(sender, "This command can only be used by a player!");
            return false;
        }

        if (args.length < 1) {
            BooksWithoutBorders.sendErrorMessage(player, "Too few command arguments!");
            return false;
        }

        ItemStack heldItem = InventoryHelper.getHeldItem(player, true);
        if (heldItem.getType() == Material.AIR) {
            BooksWithoutBorders.sendErrorMessage(sender, "You must be holding an item to set title!");
            return false;
        }

        String title = String.join(" ", args);
        title = ChatColor.translateAlternateColorCodes('&', title);

        ItemMeta itemMetadata = heldItem.getItemMeta();
        if (itemMetadata == null) {
            BooksWithoutBorders.sendErrorMessage(sender, "Unable to get metadata for your held item!");
            return false;
        }

        //Get and change metadata
        ItemMeta newMetaData;
        if (heldItem.getType() == Material.WRITTEN_BOOK) {
            BookMeta bookMetadata = (BookMeta) itemMetadata;
            bookMetadata.setTitle(title);
            newMetaData = bookMetadata;
        } else {
            itemMetadata.setDisplayName(title);
            newMetaData = itemMetadata;
        }

        //Set the new metadata
        heldItem.setItemMeta(newMetaData);
        BooksWithoutBorders.sendSuccessMessage(sender, "Title set to " + title + "!");
        return true;
    }

    @Override
    public List<String> onTabComplete(@NotNull CommandSender sender, @NotNull Command command, @NotNull String alias, @NotNull String[] args) {
        List<String> options = new ArrayList<>();
        options.add("<new title>");
        return options;
    }

}
