package net.knarcraft.bookswithoutborders.command;

import net.knarcraft.bookswithoutborders.BooksWithoutBorders;
import net.knarcraft.bookswithoutborders.state.ItemSlot;
import net.knarcraft.bookswithoutborders.utility.InventoryHelper;
import org.bukkit.Material;
import org.bukkit.command.Command;
import org.bukkit.command.CommandSender;
import org.bukkit.command.TabExecutor;
import org.bukkit.entity.Player;
import org.bukkit.inventory.ItemStack;
import org.bukkit.inventory.meta.BookMeta;
import org.jetbrains.annotations.NotNull;

import java.util.ArrayList;
import java.util.List;

/**
 * Command executor for the unsign command
 */
public class CommandUnSign implements TabExecutor {

    @Override
    public boolean onCommand(@NotNull CommandSender sender, @NotNull Command command, @NotNull String label, @NotNull String[] args) {
        if (!(sender instanceof Player player)) {
            BooksWithoutBorders.sendErrorMessage(sender, "This command can only be used by a player!");
            return false;
        }

        if (InventoryHelper.notHoldingOneWrittenBookCheck(player, "You must be holding a signed book to unsign it!",
                "You cannot unsign two books at once. Please un-equip one of the books you're holding!")) {
            return false;
        }

        //Find which hand the player is using to hold the book. If holding one in each, throw an error
        ItemSlot holdingSlot = InventoryHelper.getHeldSlotBook(player, false, false, true, true);
        unSignHeldBook(player, holdingSlot == ItemSlot.MAIN_HAND);
        return true;
    }

    /**
     * Un-signs the player's currently held book
     *
     * @param player   <p>The player holding the book</p>
     * @param mainHand <p>Whether the player is holding the book in its main hand or its off hand</p>
     */
    public void unSignHeldBook(Player player, boolean mainHand) {
        //Get the old book
        BookMeta oldBook = InventoryHelper.getHeldBookMetadata(player, mainHand);

        //UnSign the book
        ItemStack newBook = new ItemStack(Material.WRITABLE_BOOK);
        newBook.setItemMeta(oldBook);

        InventoryHelper.replaceHeldItem(player, newBook, mainHand);
    }

    @Override
    public List<String> onTabComplete(@NotNull CommandSender sender, @NotNull Command command, @NotNull String alias, @NotNull String[] args) {
        return new ArrayList<>();
    }

}
