package net.knarcraft.bookswithoutborders.config;

/**
 * A representation of the different available config options
 */
public enum ConfigOption {

    /**
     * Whether YAML should be used to store books instead of simple text files
     */
    USE_YAML("Options.Save_Books_in_Yaml_Format", true),

    /**
     * The max duplicates of a book that can be saved
     */
    MAX_DUPLICATES("Options.Max_Number_of_Duplicates", 5),

    /**
     * The separator used to separate book title and book author
     */
    TITLE_AUTHOR_SEPARATOR("Options.Title-Author_Separator", ","),

    /**
     * The separator used to specify a new line in an item's lore
     */
    LORE_LINE_SEPARATOR("Options.Lore_line_separator", "~"),

    /**
     * The books given to new players when they first join
     */
    BOOKS_FOR_NEW_PLAYERS("Options.Books_for_new_players", "[]"),

    /**
     * The message to display to new players when they first join
     */
    MESSAGE_FOR_NEW_PLAYERS("Options.Message_for_new_players", ""),

    /**
     * The item type used to pay for book copying
     */
    PRICE_ITEM_TYPE("Options.Price_to_create_book.Item_type", ""),

    /**
     * The amount of items used to pay for book copying
     */
    PRICE_QUANTITY("Options.Price_to_create_book.Required_quantity", 0.0),

    /**
     * Whether admins should be able to decrypt books for all groups
     */
    ADMIN_AUTO_DECRYPT("Options.Admin_Auto_Decrypt", false),

    /**
     * Whether only the book author should be able to copy a book
     */
    AUTHOR_ONLY_COPY("Options.Author_Only_Copy", false),

    /**
     * Whether to automatically format every signed book
     */
    FORMAT_AFTER_SIGNING("Options.Format_Book_After_Signing", false);

    private final String configNode;
    private final Object defaultValue;

    /**
     * Instantiates a new config option
     *
     * @param configNode   <p>The config node in the config file this option represents</p>
     * @param defaultValue <p>The default value for this config option</p>
     */
    ConfigOption(String configNode, Object defaultValue) {
        this.configNode = configNode;
        this.defaultValue = defaultValue;
    }

    /**
     * Gets the config node used for loading/saving this config value
     *
     * @return <p>The config node</p>
     */
    public String getConfigNode() {
        return this.configNode;
    }

    /**
     * Gets the default value of this config option
     *
     * @return <p>The default value of this config option</p>
     */
    public Object getDefaultValue() {
        return this.defaultValue;
    }

}
