package net.knarcraft.bookswithoutborders.utility;

import java.util.ArrayList;
import java.util.List;

/**
 * Helper class for cleaning input and names
 */
public final class InputCleaningHelper {

    private InputCleaningHelper() {
    }

    /**
     * Removes null and empty items from a list
     *
     * @param list <p>The list to clean</p>
     * @return <p>A clean list containing all relevant values</p>
     */
    public static List<String> cleanList(List<String> list) {
        List<String> resultList = new ArrayList<>(list);
        resultList.removeIf((item) -> item == null || item.trim().isEmpty());
        return resultList;
    }

    /**
     * Removes any special character from a filename
     *
     * @param fileName <p>The file name to clean</p>
     * @return <p>The cleaned file name</p>
     */
    public static String cleanString(String fileName) {
        fileName = fileName.replace("/", "");
        fileName = fileName.replace("\\", "");
        fileName = fileName.replace("*", "");
        fileName = fileName.replace(":", "");
        fileName = fileName.replace("|", "");
        fileName = fileName.replace("<", "");
        fileName = fileName.replace(">", "");
        fileName = fileName.replace("?", "");
        fileName = fileName.replace("\"", "");
        return fileName;
    }

    /**
     * Changes spaces to underscores or underscores to spaces, depending on context
     *
     * @param fileName  <p>The file name to fix</p>
     * @param isLoading <p>Whether loading from a file as opposed to saving to a file</p>
     * @return <p>The fixed name</p>
     */
    public static String fixName(String fileName, Boolean isLoading) {
        if (isLoading) {
            fileName = fileName.replace("_", " ");
        } else {
            fileName = fileName.replace(" ", "_");
        }
        return fileName;
    }

}
