package net.knarcraft.bookswithoutborders.utility;

import java.util.ArrayList;
import java.util.List;

/**
 * Helper class for getting string lists required for auto-completion
 */
public final class TabCompletionHelper {

    private TabCompletionHelper() {
    }

    /**
     * Gets a list of booleans
     *
     * @return <p>A list of booleans</p>
     */
    public static List<String> getBooleans() {
        List<String> booleans = new ArrayList<>();
        booleans.add("true");
        booleans.add("false");
        return booleans;
    }

    /**
     * Gets a list of numbers in increasing order
     *
     * @param start <p>The start number</p>
     * @param end   <p>The end number</p>
     * @return <p>A list of numbers</p>
     */
    public static List<String> getNumbers(int start, int end) {
        List<String> numbers = new ArrayList<>();
        for (int i = start; i <= end; i++) {
            numbers.add(String.valueOf(i));
        }
        return numbers;
    }

    /**
     * Gets a list of booleans and numbers
     *
     * @param start <p>The start number</p>
     * @param end   <p>The end number</p>
     * @return <p>A list of booleans and numbers</p>
     */
    public static List<String> getBooleansAndNumbers(int start, int end) {
        List<String> booleansAndNumbers = new ArrayList<>();
        List<String> booleans = getBooleans();
        List<String> numbers = getNumbers(start, end);
        booleansAndNumbers.addAll(booleans);
        booleansAndNumbers.addAll(numbers);
        return booleansAndNumbers;
    }

}
